==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/user/messages/ru/profile.php <==
<?php

return [
    '%y Years' => '%y лет',
    '<b>This profile stream is still empty!</b>' => '<b>Лента этого профиля пока ещё пуста!</b>',
    '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Лента этого профиля пока ещё пуста!</b><br>Будьте первым и опубликуйте что-нибудь ...',
    '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<b>Лента этого профиля пока ещё пуста!</b><br>Напишите и опубликуйте что-нибудь ...',
    '<strong>About</strong> this user' => '<strong>Информация</strong> о пользователе',
    '<strong>Profile</strong> menu' => '<strong>Меню профиля</strong>',
    'About' => 'Обо мне',
    'Allow other selection' => 'Разрешить другой выбор',
    'Birthday' => 'День рождения',
    'Birthday field options' => 'Опции поля дня рождения',
    'Checkbox' => 'Чекбокс',
    'Checkbox List' => 'Список Чекбоксов',
    'Checkbox field options' => 'Настройки чекбокса',
    'City' => 'Город',
    'Comma separated country codes, e.g. DE,EN,AU' => 'Коды стран, разделенные запятыми, например: RU, EN, DE',
    'Communication' => 'Контакты',
    'Country' => 'Страна',
    'Created at' => 'Создано в',
    'Created by' => 'Создано пользователем',
    'Creation date of the user' => 'Дата создания пользователя',
    'Date' => 'Дата',
    'Date(-time) field options' => 'Опции поля даты и времени',
    'Datetime' => 'Дата и время',
    'Default value' => 'Значение по умолчанию',
    'Description' => 'Описание',
    'E-Mail' => 'Email',
    'E-mail address of the user' => 'E-mail пользователя',
    'Edit account' => 'Редактировать учётную запись',
    'Editable' => 'Доступно для редактирования',
    'Facebook URL' => 'Страница на Facebook',
    'Fax' => 'Факс',
    'Female' => 'Женский',
    'Field Type could not be changed!' => 'Тип поля не может быть изменен!',
    'Fieldtype' => 'Тип поля',
    'First name' => 'Имя',
    'Followers' => 'Подписчики',
    'Following' => 'Подписан(а)',
    'Friends' => 'Друзья',
    'Gender' => 'Пол',
    'General' => 'Основная информация',
    'Hide age per default' => 'Скрывать возраст по умолчанию',
    'Hide year in profile' => 'Скрывать год рождения в профиле',
    'ID' => 'ID',
    'Instagram URL' => 'URL-адрес Instagram',
    'Internal Name' => 'Внутренний ID',
    'Internal name already in use!' => 'Такой ID уже используется!',
    'Internal name could not be changed!' => 'Внутренний ID невозможно будет изменить!',
    'Invalid field type!' => 'Некорректный тип поля!',
    'Invalid!' => 'Ошибка!',
    'LDAP Attribute' => 'Атрибут LDAP',
    'Last login date of the user' => 'Дата последнего входа пользователя',
    'Last name' => 'Фамилия',
    'Link Prefix (e.g. https://, mailto:, tel://)' => 'Префикс ссылки (например, https://, mailto:, tel://)',
    'LinkedIn URL' => 'Страница на LinkedIn',
    'Male' => 'Мужской',
    'Markdown' => 'Markdown',
    'Maximum length' => 'Максимальная длина',
    'Maximum value' => 'Максимальное значение',
    'Minimum length' => 'Минимальная длина',
    'Minimum value' => 'Минимальное значение',
    'Mobile' => 'Телефон',
    'Module' => 'Модуль',
    'Must contain at least one character.' => 'Должен содержать хотя бы один символ.',
    'Number' => 'Номер',
    'Number field options' => 'Опции числового поля',
    'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Каждая опция должна быть на отдельной строке. Ключ=>Значение (например да=>Да)',
    'Only alphanumeric characters allowed!' => 'Допускаются только буквенно-цифровые символы!',
    'Other:' => 'Другое:',
    'Phone Private' => 'Личный телефон',
    'Phone Work' => 'Рабочий телефон',
    'Please select:' => 'Пожалуйста выберите:',
    'Possible values' => 'Допустимые значения',
    'Profile Field Category' => 'Категория профиля',
    'Regular Expression: Error message' => 'Регулярное выражение: Сообщение об ошибке',
    'Regular Expression: Validator' => 'Регулярное выражение: Валидатор',
    'Required' => 'Обязательное',
    'Searchable' => 'Доступно для поиска',
    'Select List' => 'Раскрывающийся список',
    'Select field options' => 'Опции раскрывающигося списка',
    'Show at registration' => 'Показывать при регистрации',
    'Show date/time picker' => 'Показать указатель даты/времени',
    'Social bookmarks' => 'Социальные сети',
    'Sort order' => 'Порядок сортировки',
    'Spaces' => 'Сообщества',
    'State' => 'Регион',
    'Stream' => 'Лента',
    'Street' => 'Улица',
    'Supported ISO3166 country codes' => 'Поддерживаются коды стран согласно ISO3166',
    'Text' => 'Текст',
    'Text Area' => 'Текстовая область',
    'Text Field Options' => 'Опции текстового поля',
    'Text area field options' => 'Опции текстовой области',
    'This profile is no longer available!' => 'Этот профиль больше не доступен!',
    'This user account is not approved yet!' => 'Эта учётная запись ещё не утверждена!',
    'This will add an additional input element for custom values' => 'Это добавит дополнительный элемент для ввода пользовательских значений',
    'TikTok URL' => 'URL-адрес TikTok',
    'Title' => 'Заголовок',
    'Translation Category ID' => 'ID категории перевода',
    'Twitter URL' => 'Страница в Twitter',
    'Type Config' => 'Тип конфигурации',
    'Updated at' => 'Обновлено',
    'Updated by' => 'Обновлено пользователем',
    'Use as Directory filter' => 'Использовать в качестве фильтра каталога',
    'Username' => 'Имя пользователя',
    'Validator' => 'Валидатор',
    'Vimeo URL' => 'Страница на Vimeo',
    'Visible' => 'Видимо',
    'Website URL' => 'Сайт',
    'XMPP Jabber Address' => 'Адрес XMPP Jabber',
    'Xing URL' => 'Страница Xing',
    'You need to login to view this user profile!' => 'Вы должны войти, чтобы посмотреть профиль этого пользователя!',
    'YouTube URL' => 'Канал на YouTube',
    'Zip' => 'Почтовый индекс',
    '{attribute} is required!' => 'Требуется указать {attribute}!',
    'Diverse' => '',
    'Mastodon URL' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/ru/profile.php <==
<?php

return [
    '%y Years' => '%y лет',
    '<b>This profile stream is still empty!</b>' => '<b>Лента этого профиля пока ещё пуста!</b>',
    '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Лента этого профиля пока ещё пуста!</b><br>Будьте первым и опубликуйте что-нибудь ...',
    '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<b>Лента этого профиля пока ещё пуста!</b><br>Напишите и опубликуйте что-нибудь ...',
    '<strong>About</strong> this user' => '<strong>Информация</strong> о пользователе',
    '<strong>Profile</strong> menu' => '<strong>Меню профиля</strong>',
    'About' => 'Обо мне',
    'Allow other selection' => 'Разрешить другой выбор',
    'Birthday' => 'День рождения',
    'Birthday field options' => 'Опции поля дня рождения',
    'Checkbox' => 'Чекбокс',
    'Checkbox List' => 'Список Чекбоксов',
    'Checkbox field options' => 'Настройки чекбокса',
    'City' => 'Город',
    'Comma separated country codes, e.g. DE,EN,AU' => 'Коды стран, разделенные запятыми, например: RU, EN, DE',
    'Communication' => 'Контакты',
    'Country' => 'Страна',
    'Created at' => 'Создано в',
    'Created by' => 'Создано пользователем',
    'Creation date of the user' => 'Дата создания пользователя',
    'Date' => 'Дата',
    'Date(-time) field options' => 'Опции поля даты и времени',
    'Datetime' => 'Дата и время',
    'Default value' => 'Значение по умолчанию',
    'Description' => 'Описание',
    'Diverse' => 'Разнополый',
    'E-Mail' => 'Email',
    'E-mail address of the user' => 'E-mail пользователя',
    'Edit account' => 'Редактировать учётную запись',
    'Editable' => 'Доступно для редактирования',
    'Facebook URL' => 'Страница на Facebook',
    'Fax' => 'Факс',
    'Female' => 'Женский',
    'Field Type could not be changed!' => 'Тип поля не может быть изменен!',
    'Fieldtype' => 'Тип поля',
    'First name' => 'Имя',
    'Followers' => 'Подписчики',
    'Following' => 'Подписан(а)',
    'Friends' => 'Друзья',
    'Gender' => 'Пол',
    'General' => 'Основная информация',
    'Hide age per default' => 'Скрывать возраст по умолчанию',
    'Hide year in profile' => 'Скрывать год рождения в профиле',
    'ID' => 'ID',
    'Instagram URL' => 'URL-адрес Instagram',
    'Internal Name' => 'Внутренний ID',
    'Internal name already in use!' => 'Такой ID уже используется!',
    'Internal name could not be changed!' => 'Внутренний ID невозможно будет изменить!',
    'Invalid field type!' => 'Некорректный тип поля!',
    'Invalid!' => 'Ошибка!',
    'LDAP Attribute' => 'Атрибут LDAP',
    'Last login date of the user' => 'Дата последнего входа пользователя',
    'Last name' => 'Фамилия',
    'Link Prefix (e.g. https://, mailto:, tel://)' => 'Префикс ссылки (например, https://, mailto:, tel://)',
    'LinkedIn URL' => 'Страница на LinkedIn',
    'Male' => 'Мужской',
    'Markdown' => 'Markdown',
    'Mastodon URL' => 'URL-адрес Mastodon',
    'Maximum length' => 'Максимальная длина',
    'Maximum value' => 'Максимальное значение',
    'Minimum length' => 'Минимальная длина',
    'Minimum value' => 'Минимальное значение',
    'Mobile' => 'Телефон',
    'Module' => 'Модуль',
    'Must contain at least one character.' => 'Должен содержать хотя бы один символ.',
    'Number' => 'Номер',
    'Number field options' => 'Опции числового поля',
    'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Каждая опция должна быть на отдельной строке. Ключ=>Значение (например да=>Да)',
    'Only alphanumeric characters allowed!' => 'Допускаются только буквенно-цифровые символы!',
    'Other:' => 'Другое:',
    'Phone Private' => 'Личный телефон',
    'Phone Work' => 'Рабочий телефон',
    'Please select:' => 'Пожалуйста выберите:',
    'Possible values' => 'Допустимые значения',
    'Profile Field Category' => 'Категория профиля',
    'Regular Expression: Error message' => 'Регулярное выражение: Сообщение об ошибке',
    'Regular Expression: Validator' => 'Регулярное выражение: Валидатор',
    'Required' => 'Обязательное',
    'Searchable' => 'Доступно для поиска',
    'Select List' => 'Раскрывающийся список',
    'Select field options' => 'Опции раскрывающигося списка',
    'Show at registration' => 'Показывать при регистрации',
    'Show date/time picker' => 'Показать указатель даты/времени',
    'Social bookmarks' => 'Социальные сети',
    'Sort order' => 'Порядок сортировки',
    'Spaces' => 'Сообщества',
    'State' => 'Регион',
    'Stream' => 'Лента',
    'Street' => 'Улица',
    'Supported ISO3166 country codes' => 'Поддерживаются коды стран согласно ISO3166',
    'Text' => 'Текст',
    'Text Area' => 'Текстовая область',
    'Text Field Options' => 'Опции текстового поля',
    'Text area field options' => 'Опции текстовой области',
    'This profile is no longer available!' => 'Этот профиль больше не доступен!',
    'This user account is not approved yet!' => 'Эта учётная запись ещё не утверждена!',
    'This will add an additional input element for custom values' => 'Это добавит дополнительный элемент для ввода пользовательских значений',
    'TikTok URL' => 'URL-адрес TikTok',
    'Title' => 'Заголовок',
    'Translation Category ID' => 'ID категории перевода',
    'Twitter URL' => 'Страница в Twitter',
    'Type Config' => 'Тип конфигурации',
    'Updated at' => 'Обновлено',
    'Updated by' => 'Обновлено пользователем',
    'Use as Directory filter' => 'Использовать в качестве фильтра каталога',
    'Username' => 'Имя пользователя',
    'Validator' => 'Валидатор',
    'Vimeo URL' => 'Страница на Vimeo',
    'Visible' => 'Видимо',
    'Website URL' => 'Сайт',
    'XMPP Jabber Address' => 'Адрес XMPP Jabber',
    'Xing URL' => 'Страница Xing',
    'You need to login to view this user profile!' => 'Вы должны войти, чтобы посмотреть профиль этого пользователя!',
    'YouTube URL' => 'Канал на YouTube',
    'Zip' => 'Почтовый индекс',
    '{attribute} is required!' => 'Требуется указать {attribute}!',
    'Each line must be formatted as Key=>Value!' => '',
    'Template' => '',
    'This profile is disabled!' => '',
    'Twig template that will be used to render this field. You can use the internal names as variables, e.g. `{{ firstname }} {{ lastname }}`' => '',
];
